@@ -4,7 +4,7 @@
 #
 # Copyright (c) 2007-2008 Peng Huang <shawn.p.huang@gmail.com>
 # Copyright (c) 2009 Hideaki ABE <abe.sendai@gmail.com>
-# Copyright (c) 2007-2010 Red Hat, Inc.
+# Copyright (c) 2007-2011 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,6 +28,11 @@ from gtk import glade
 from ibus import keysyms, modifier, Bus
 from gettext import dgettext, bindtextdomain
 
+try:
+    from locale import getpreferredencoding
+except:
+    pass
+
 from anthyprefs import AnthyPrefs
 
 
@@ -183,6 +188,14 @@ class AnthySetup(object):
         about_vbox = self.xml.get_widget("about_vbox")
 
         about_dialog.set_version(self.prefs.get_version())
+        try:
+            if getpreferredencoding().lower() == "utf-8":
+                copyright = about_dialog.get_copyright()
+                copyright = copyright.replace('(c)', '\xc2\xa9')
+                copyright = copyright.replace('-', '\xe2\x80\x93')
+                about_dialog.set_copyright(copyright)
+        except:
+            pass
         if icon_path != None:
             image = gtk.image_new_from_file(icon_path)
             about_dialog.set_logo(image.get_pixbuf())
@@ -528,6 +541,8 @@ class AnthySetup(object):
             return self.prefs.get_value('dict', 'anthy_zipcode')[0]
         elif selected_id == 'ibus_symbol':
             return self.prefs.get_value('dict', 'ibus_symbol')[0]
+        elif selected_id == 'ibus_oldchar':
+            return self.prefs.get_value('dict', 'ibus_oldchar')[0]
         for file in files:
             id = self.__get_quoted_id(file)
             if selected_id == id:
@@ -573,6 +588,8 @@ class AnthySetup(object):
                 id = 'anthy_zipcode'
             elif file in prefs.get_value('dict', 'ibus_symbol'):
                 id = 'ibus_symbol'
+            elif file in prefs.get_value('dict', 'ibus_oldchar'):
+                id = 'ibus_oldchar'
             else:
                 id = self.__get_quoted_id(file)
                 section = 'dict/file/' + id
